#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 cabal-install-parsers
version:              0.6.1.1
visibility:           public
id:                   cabal-install-parsers-0.6.1.1-B8pGbPjfrONByR7TwJG6NU
key:                  cabal-install-parsers-0.6.1.1-B8pGbPjfrONByR7TwJG6NU
license:              GPL-2.0-or-later AND BSD-3-Clause
maintainer:           hvr@gnu.org, oleg.grenrus@iki.fi
author:               Herbert Valerio Riedel, Oleg Grenrus
homepage:             https://haskell-ci.rtfd.org/
synopsis:             Utilities to work with cabal-install files
description:
    @cabal-install-parsers@ provides parsers for @cabal-install@ files:
    @cabal.project@ ("Cabal.Project"),
    @cabal.config@ ("Cabal.Config"),
    @01-index.tar@ ("Cabal.Index");
    as well as some other utilities.

    The feature set is mainly motivated by the needs of @haskell-ci@ package.
    The parsed data is not complete, functionality is added on demand.

category:             Development
abi:                  ab45d83f1a00bf74840e34d83be58f03
exposed:              True
exposed-modules:
    Cabal.Config Cabal.Index Cabal.Optimization Cabal.Package
    Cabal.Parse Cabal.Project Cabal.SourceRepo

hidden-modules:       Cabal.Internal.Glob Cabal.Internal.Newtypes
import-dirs:          /usr/lib/ghc-9.6.6/site-local/cabal-install-parsers-0.6.1.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/cabal-install-parsers-0.6.1.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/cabal-install-parsers-0.6.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-cabal-install-parsers
hs-libraries:         HScabal-install-parsers-0.6.1.1-B8pGbPjfrONByR7TwJG6NU
depends:
    Cabal-syntax-3.10.3.0 aeson-2.2.2.0-EED32RMVwDLAiFjSZ5pcFd
    base-4.18.2.1 base16-bytestring-1.0.2.0-DM0PdKLhSbY52pPQqueZ2n
    binary-0.8.9.1 binary-instances-1.0.5-LmdE9cGeU7hKgAOoSo8nIi
    bytestring-0.11.5.3 containers-0.6.7
    cryptohash-sha256-0.11.102.1-ELw3M6a4GcjFwqR04bpUI4 deepseq-1.4.8.1
    directory-1.3.8.5 filepath-1.4.300.1
    lukko-0.1.2-4XDQyyTCh9AFPiNxUrlTId
    network-uri-2.6.4.2-AAuJwobb8qV67gBUtHYQFB parsec-3.1.16.1
    pretty-1.1.3.6 tar-0.6.0.0-993o463G7pSBUsDuWmvfYg text-2.0.2
    time-1.12.2 transformers-0.6.1.0

haddock-interfaces:
    /usr/share/doc/haskell-cabal-install-parsers/html/cabal-install-parsers.haddock

haddock-html:         /usr/share/doc/haskell-cabal-install-parsers/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

